==> ph-schematron-2.8.4-sources.jar: org/oclc/purl/dsdl/svrl/SchematronOutputType.java <==

package org.oclc.purl.dsdl.svrl;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Nonnegative;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.helger.commons.annotations.ReturnsMutableObject;
import com.helger.commons.equals.EqualsUtils;
import com.helger.commons.hash.HashCodeGenerator;
import com.helger.commons.string.ToStringGenerator;


/**
 * <p>Java class for SchematronOutputType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SchematronOutputType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://purl.oclc.org/dsdl/svrl}text" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://purl.oclc.org/dsdl/svrl}ns-prefix-in-attribute-values" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;sequence maxOccurs="unbounded">
 *           &lt;element ref="{http://purl.oclc.org/dsdl/svrl}active-pattern"/>
 *           &lt;sequence maxOccurs="unbounded" minOccurs="0">
 *             &lt;element ref="{http://purl.oclc.org/dsdl/svrl}fired-rule"/>
 *             &lt;choice maxOccurs="unbounded" minOccurs="0">
 *               &lt;element ref="{http://purl.oclc.org/dsdl/svrl}failed-assert"/>
 *               &lt;element ref="{http://purl.oclc.org/dsdl/svrl}successful-report"/>
 *             &lt;/choice>
 *           &lt;/sequence>
 *         &lt;/sequence>
 *       &lt;/sequence>
 *       &lt;attribute name="title" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
 *       &lt;attribute name="phase" type="{http://www.w3.org/2001/XMLSchema}NMTOKEN" />
 *       &lt;attribute name="schemaVersion" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SchematronOutputType", propOrder = {
    "text",
    "nsPrefixInAttributeValues",
    "activePatternAndFiredRuleAndFailedAssert"
})
public class SchematronOutputType implements Serializable
{

    private List<String> text;
    @XmlElement(name = "ns-prefix-in-attribute-values")
    private List<NsPrefixInAttributeValues> nsPrefixInAttributeValues;
    @XmlElements({
        @XmlElement(name = "active-pattern", required = true, type = ActivePattern.class),
        @XmlElement(name = "fired-rule", required = true, type = FiredRule.class),
        @XmlElement(name = "failed-assert", required = true, type = FailedAssert.class),
        @XmlElement(name = "successful-report", required = true, type = SuccessfulReport.class)
    })
    private List<Object> activePatternAndFiredRuleAndFailedAssert;
    @XmlAttribute(name = "title")
    @XmlSchemaType(name = "anySimpleType")
    private String title;
    @XmlAttribute(name = "phase")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlSchemaType(name = "NMTOKEN")
    private String phase;
    @XmlAttribute(name = "schemaVersion")
    @XmlSchemaType(name = "anySimpleType")
    private String schemaVersion;

    /**
     * Gets the value of the text property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the text property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getText().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    @Nonnull
    @ReturnsMutableObject(reason = "JAXB implementation style")
    public List<String> getText() {
        if (text == null) {
            text = new ArrayList<String>();
        }
        return this.text;
    }

    /**
     * Gets the value of the nsPrefixInAttributeValues property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nsPrefixInAttributeValues property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNsPrefixInAttributeValues().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link NsPrefixInAttributeValues }
     * 
     * 
     */
    @Nonnull
    @ReturnsMutableObject(reason = "JAXB implementation style")
    public List<NsPrefixInAttributeValues> getNsPrefixInAttributeValues() {
        if (nsPrefixInAttributeValues == null) {
            nsPrefixInAttributeValues = new ArrayList<NsPrefixInAttributeValues>();
        }
        return this.nsPrefixInAttributeValues;
    }

    /**
     * Gets the value of the activePatternAndFiredRuleAndFailedAssert property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the activePatternAndFiredRuleAndFailedAssert property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getActivePatternAndFiredRuleAndFailedAssert().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ActivePattern }
     * {@link FiredRule }
     * {@link FailedAssert }
     * {@link SuccessfulReport }
     * 
     * 
     */
    @Nonnull
    @ReturnsMutableObject(reason = "JAXB implementation style")
    public List<Object> getActivePatternAndFiredRuleAndFailedAssert() {
        if (activePatternAndFiredRuleAndFailedAssert == null) {
            activePatternAndFiredRuleAndFailedAssert = new ArrayList<Object>();
        }
        return this.activePatternAndFiredRuleAndFailedAssert;
    }

    /**
     * Gets the value of the title property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Nullable
    public String getTitle() {
        return title;
    }

    /**
     * Sets the value of the title property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTitle(
        @Nullable
        String value) {
        this.title = value;
    }

    /**
     * Gets the value of the phase property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Nullable
    public String getPhase() {
        return phase;
    }

    /**
     * Sets the value of the phase property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPhase(
        @Nullable
        String value) {
        this.phase = value;
    }

    /**
     * Gets the value of the schemaVersion property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Nullable
    public String getSchemaVersion() {
        return schemaVersion;
    }

    /**
     * Sets the value of the schemaVersion property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSchemaVersion(
        @Nullable
        String value) {
        this.schemaVersion = value;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public boolean equals(final Object o) {
        if (o == this) {
            return true;
        }
        if ((o == null)||(!getClass().equals(o.getClass()))) {
            return false;
        }
        final SchematronOutputType rhs = ((SchematronOutputType) o);
        if (!EqualsUtils.equals(text, rhs.text)) {
            return false;
        }
        if (!EqualsUtils.equals(nsPrefixInAttributeValues, rhs.nsPrefixInAttributeValues)) {
            return false;
        }
        if (!EqualsUtils.equals(activePatternAndFiredRuleAndFailedAssert, rhs.activePatternAndFiredRuleAndFailedAssert)) {
            return false;
        }
        if (!EqualsUtils.equals(title, rhs.title)) {
            return false;
        }
        if (!EqualsUtils.equals(phase, rhs.phase)) {
            return false;
        }
        if (!EqualsUtils.equals(schemaVersion, rhs.schemaVersion)) {
            return false;
        }
        return true;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public int hashCode() {
        return new HashCodeGenerator(this).append(text).append(nsPrefixInAttributeValues).append(activePatternAndFiredRuleAndFailedAssert).append(title).append(phase).append(schemaVersion).getHashCode();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-tostring
     * 
     */
    @Override
    public String toString() {
        return new ToStringGenerator(this).append("text", text).append("nsPrefixInAttributeValues", nsPrefixInAttributeValues).append("activePatternAndFiredRuleAndFailedAssert", activePatternAndFiredRuleAndFailedAssert).append("title", title).append("phase", phase).append("schemaVersion", schemaVersion).toString();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param aList
     *     The new list member to set. May be <code>null</code>.
     */
    public void setText(
        @Nullable
        final List<String> aList) {
        text = aList;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param aList
     *     The new list member to set. May be <code>null</code>.
     */
    public void setNsPrefixInAttributeValues(
        @Nullable
        final List<NsPrefixInAttributeValues> aList) {
        nsPrefixInAttributeValues = aList;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param aList
     *     The new list member to set. May be <code>null</code>.
     */
    public void setActivePatternAndFiredRuleAndFailedAssert(
        @Nullable
        final List<Object> aList) {
        activePatternAndFiredRuleAndFailedAssert = aList;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     <code>true</code> if at least one item is contained, <code>false</code> otherwise.
     */
    public boolean hasTextEntries() {
        return (!getText().isEmpty());
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     <code>true</code> if no item is contained, <code>false</code> otherwise.
     */
    public boolean hasNoTextEntries() {
        return getText().isEmpty();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     The number of contained elements. Always &ge; 0.
     */
    @Nonnegative
    public int getTextCount() {
        return getText().size();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param index
     *     The index to retrieve
     * @return
     *     The element at the specified index. May be <code>null</code>
     * @throws ArrayIndexOutOfBoundsException
     *     if the index is invalid!
     */
    @Nullable
    public String getTextAtIndex(
        @Nonnegative
        final int index) {
        return getText().get(index);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     <code>true</code> if at least one item is contained, <code>false</code> otherwise.
     */
    public boolean hasNsPrefixInAttributeValuesEntries() {
        return (!getNsPrefixInAttributeValues().isEmpty());
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     <code>true</code> if no item is contained, <code>false</code> otherwise.
     */
    public boolean hasNoNsPrefixInAttributeValuesEntries() {
        return getNsPrefixInAttributeValues().isEmpty();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     The number of contained elements. Always &ge; 0.
     */
    @Nonnegative
    public int getNsPrefixInAttributeValuesCount() {
        return getNsPrefixInAttributeValues().size();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param index
     *     The index to retrieve
     * @return
     *     The element at the specified index. May be <code>null</code>
     * @throws ArrayIndexOutOfBoundsException
     *     if the index is invalid!
     */
    @Nullable
    public NsPrefixInAttributeValues getNsPrefixInAttributeValuesAtIndex(
        @Nonnegative
        final int index) {
        return getNsPrefixInAttributeValues().get(index);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     <code>true</code> if at least one item is contained, <code>false</code> otherwise.
     */
    public boolean hasActivePatternAndFiredRuleAndFailedAssertEntries() {
        return (!getActivePatternAndFiredRuleAndFailedAssert().isEmpty());
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     <code>true</code> if no item is contained, <code>false</code> otherwise.
     */
    public boolean hasNoActivePatternAndFiredRuleAndFailedAssertEntries() {
        return getActivePatternAndFiredRuleAndFailedAssert().isEmpty();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     The number of contained elements. Always &ge; 0.
     */
    @Nonnegative
    public int getActivePatternAndFiredRuleAndFailedAssertCount() {
        return getActivePatternAndFiredRuleAndFailedAssert().size();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param index
     *     The index to retrieve
     * @return
     *     The element at the specified index. May be <code>null</code>
     * @throws ArrayIndexOutOfBoundsException
     *     if the index is invalid!
     */
    @Nullable
    public Object getActivePatternAndFiredRuleAndFailedAssertAtIndex(
        @Nonnegative
        final int index) {
        return getActivePatternAndFiredRuleAndFailedAssert().get(index);
    }

}

==> ph-schematron-3.0.0-sources.jar: org/oclc/purl/dsdl/svrl/SchematronOutputType.java <==

package org.oclc.purl.dsdl.svrl;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Nonnegative;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import com.helger.commons.annotation.ReturnsMutableObject;
import com.helger.commons.equals.EqualsHelper;
import com.helger.commons.hashcode.HashCodeGenerator;
import com.helger.commons.string.ToStringGenerator;


/**
 * <p>Java class for SchematronOutputType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SchematronOutputType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://purl.oclc.org/dsdl/svrl}text" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;element ref="{http://purl.oclc.org/dsdl/svrl}ns-prefix-in-attribute-values" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;sequence maxOccurs="unbounded"&gt;
 *           &lt;element ref="{http://purl.oclc.org/dsdl/svrl}active-pattern"/&gt;
 *           &lt;sequence maxOccurs="unbounded" minOccurs="0"&gt;
 *             &lt;element ref="{http://purl.oclc.org/dsdl/svrl}fired-rule"/&gt;
 *             &lt;choice maxOccurs="unbounded" minOccurs="0"&gt;
 *               &lt;element ref="{http://purl.oclc.org/dsdl/svrl}failed-assert"/&gt;
 *               &lt;element ref="{http://purl.oclc.org/dsdl/svrl}successful-report"/&gt;
 *             &lt;/choice&gt;
 *           &lt;/sequence&gt;
 *         &lt;/sequence&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="title" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" /&gt;
 *       &lt;attribute name="phase" type="{http://www.w3.org/2001/XMLSchema}NMTOKEN" /&gt;
 *       &lt;attribute name="schemaVersion" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SchematronOutputType", propOrder = {
    "text",
    "nsPrefixInAttributeValues",
    "activePatternAndFiredRuleAndFailedAssert"
})
@CodingStyleguideUnaware
public class SchematronOutputType implements Serializable
{

    private List<String> text;
    @XmlElement(name = "ns-prefix-in-attribute-values")
    private List<NsPrefixInAttributeValues> nsPrefixInAttributeValues;
    @XmlElements({
        @XmlElement(name = "active-pattern", required = true, type = ActivePattern.class),
        @XmlElement(name = "fired-rule", required = true, type = FiredRule.class),
        @XmlElement(name = "failed-assert", required = true, type = FailedAssert.class),
        @XmlElement(name = "successful-report", required = true, type = SuccessfulReport.class)
    })
    private List<Object> activePatternAndFiredRuleAndFailedAssert;
    @XmlAttribute(name = "title")
    @XmlSchemaType(name = "anySimpleType")
    private String title;
    @XmlAttribute(name = "phase")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlSchemaType(name = "NMTOKEN")
    private String phase;
    @XmlAttribute(name = "schemaVersion")
    @XmlSchemaType(name = "anySimpleType")
    private String schemaVersion;

    /**
     * Gets the value of the text property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the text property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getText().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * 
     * 
     */
    @Nonnull
    @ReturnsMutableObject("JAXB implementation style")
    public List<String> getText() {
        if (text == null) {
            text = new ArrayList<String>();
        }
        return this.text;
    }

    /**
     * Gets the value of the nsPrefixInAttributeValues property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nsPrefixInAttributeValues property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNsPrefixInAttributeValues().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link NsPrefixInAttributeValues }
     * 
     * 
     */
    @Nonnull
    @ReturnsMutableObject("JAXB implementation style")
    public List<NsPrefixInAttributeValues> getNsPrefixInAttributeValues() {
        if (nsPrefixInAttributeValues == null) {
            nsPrefixInAttributeValues = new ArrayList<NsPrefixInAttributeValues>();
        }
        return this.nsPrefixInAttributeValues;
    }

    /**
     * Gets the value of the activePatternAndFiredRuleAndFailedAssert property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the activePatternAndFiredRuleAndFailedAssert property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getActivePatternAndFiredRuleAndFailedAssert().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ActivePattern }
     * {@link FiredRule }
     * {@link FailedAssert }
     * {@link SuccessfulReport }
     * 
     * 
     */
    @Nonnull
    @ReturnsMutableObject("JAXB implementation style")
    public List<Object> getActivePatternAndFiredRuleAndFailedAssert() {
        if (activePatternAndFiredRuleAndFailedAssert == null) {
            activePatternAndFiredRuleAndFailedAssert = new ArrayList<Object>();
        }
        return this.activePatternAndFiredRuleAndFailedAssert;
    }

    /**
     * Gets the value of the title property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Nullable
    public String getTitle() {
        return title;
    }

    /**
     * Sets the value of the title property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTitle(
        @Nullable
        String value) {
        this.title = value;
    }

    /**
     * Gets the value of the phase property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Nullable
    public String getPhase() {
        return phase;
    }

    /**
     * Sets the value of the phase property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPhase(
        @Nullable
        String value) {
        this.phase = value;
    }

    /**
     * Gets the value of the schemaVersion property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @Nullable
    public String getSchemaVersion() {
        return schemaVersion;
    }

    /**
     * Sets the value of the schemaVersion property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSchemaVersion(
        @Nullable
        String value) {
        this.schemaVersion = value;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public boolean equals(final Object o) {
        if (o == this) {
            return true;
        }
        if ((o == null)||(!getClass().equals(o.getClass()))) {
            return false;
        }
        final SchematronOutputType rhs = ((SchematronOutputType) o);
        if (!EqualsHelper.equals(text, rhs.text)) {
            return false;
        }
        if (!EqualsHelper.equals(nsPrefixInAttributeValues, rhs.nsPrefixInAttributeValues)) {
            return false;
        }
        if (!EqualsHelper.equals(activePatternAndFiredRuleAndFailedAssert, rhs.activePatternAndFiredRuleAndFailedAssert)) {
            return false;
        }
        if (!EqualsHelper.equals(title, rhs.title)) {
            return false;
        }
        if (!EqualsHelper.equals(phase, rhs.phase)) {
            return false;
        }
        if (!EqualsHelper.equals(schemaVersion, rhs.schemaVersion)) {
            return false;
        }
        return true;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public int hashCode() {
        return new HashCodeGenerator(this).append(text).append(nsPrefixInAttributeValues).append(activePatternAndFiredRuleAndFailedAssert).append(title).append(phase).append(schemaVersion).getHashCode();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-tostring
     * 
     */
    @Override
    public String toString() {
        return new ToStringGenerator(this).append("text", text).append("nsPrefixInAttributeValues", nsPrefixInAttributeValues).append("activePatternAndFiredRuleAndFailedAssert", activePatternAndFiredRuleAndFailedAssert).append("title", title).append("phase", phase).append("schemaVersion", schemaVersion).toString();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param aList
     *     The new list member to set. May be <code>null</code>.
     */
    public void setText(
        @Nullable
        final List<String> aList) {
        text = aList;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param aList
     *     The new list member to set. May be <code>null</code>.
     */
    public void setNsPrefixInAttributeValues(
        @Nullable
        final List<NsPrefixInAttributeValues> aList) {
        nsPrefixInAttributeValues = aList;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param aList
     *     The new list member to set. May be <code>null</code>.
     */
    public void setActivePatternAndFiredRuleAndFailedAssert(
        @Nullable
        final List<Object> aList) {
        activePatternAndFiredRuleAndFailedAssert = aList;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     <code>true</code> if at least one item is contained, <code>false</code> otherwise.
     */
    public boolean hasTextEntries() {
        return (!getText().isEmpty());
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     <code>true</code> if no item is contained, <code>false</code> otherwise.
     */
    public boolean hasNoTextEntries() {
        return getText().isEmpty();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     The number of contained elements. Always &ge; 0.
     */
    @Nonnegative
    public int getTextCount() {
        return getText().size();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param index
     *     The index to retrieve
     * @return
     *     The element at the specified index. May be <code>null</code>
     * @throws ArrayIndexOutOfBoundsException
     *     if the index is invalid!
     */
    @Nullable
    public String getTextAtIndex(
        @Nonnegative
        final int index) {
        return getText().get(index);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param elem
     *     The element to be added. May not be <code>null</code>.
     */
    public void addText(
        @Nonnull
        final String elem) {
        getText().add(elem);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     <code>true</code> if at least one item is contained, <code>false</code> otherwise.
     */
    public boolean hasNsPrefixInAttributeValuesEntries() {
        return (!getNsPrefixInAttributeValues().isEmpty());
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     <code>true</code> if no item is contained, <code>false</code> otherwise.
     */
    public boolean hasNoNsPrefixInAttributeValuesEntries() {
        return getNsPrefixInAttributeValues().isEmpty();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     The number of contained elements. Always &ge; 0.
     */
    @Nonnegative
    public int getNsPrefixInAttributeValuesCount() {
        return getNsPrefixInAttributeValues().size();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param index
     *     The index to retrieve
     * @return
     *     The element at the specified index. May be <code>null</code>
     * @throws ArrayIndexOutOfBoundsException
     *     if the index is invalid!
     */
    @Nullable
    public NsPrefixInAttributeValues getNsPrefixInAttributeValuesAtIndex(
        @Nonnegative
        final int index) {
        return getNsPrefixInAttributeValues().get(index);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param elem
     *     The element to be added. May not be <code>null</code>.
     */
    public void addNsPrefixInAttributeValues(
        @Nonnull
        final NsPrefixInAttributeValues elem) {
        getNsPrefixInAttributeValues().add(elem);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     <code>true</code> if at least one item is contained, <code>false</code> otherwise.
     */
    public boolean hasActivePatternAndFiredRuleAndFailedAssertEntries() {
        return (!getActivePatternAndFiredRuleAndFailedAssert().isEmpty());
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     <code>true</code> if no item is contained, <code>false</code> otherwise.
     */
    public boolean hasNoActivePatternAndFiredRuleAndFailedAssertEntries() {
        return getActivePatternAndFiredRuleAndFailedAssert().isEmpty();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @return
     *     The number of contained elements. Always &ge; 0.
     */
    @Nonnegative
    public int getActivePatternAndFiredRuleAndFailedAssertCount() {
        return getActivePatternAndFiredRuleAndFailedAssert().size();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param index
     *     The index to retrieve
     * @return
     *     The element at the specified index. May be <code>null</code>
     * @throws ArrayIndexOutOfBoundsException
     *     if the index is invalid!
     */
    @Nullable
    public Object getActivePatternAndFiredRuleAndFailedAssertAtIndex(
        @Nonnegative
        final int index) {
        return getActivePatternAndFiredRuleAndFailedAssert().get(index);
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-list-extension
     * 
     * @param elem
     *     The element to be added. May not be <code>null</code>.
     */
    public void addActivePatternAndFiredRuleAndFailedAssert(
        @Nonnull
        final Object elem) {
        getActivePatternAndFiredRuleAndFailedAssert().add(elem);
    }

}
